get_tree_bee_n100: Get 100 randomly selected mega-trees of Bees from Bee Tree of...

View source: R/get_large_trees.R

get_tree_bee_n100R Documentation

Get 100 randomly selected mega-trees of Bees from Bee Tree of Life

Description

Because of the large file size (~5 MB), this dataset is not bundled with the package and is downloaded and cached locally on first use.

Usage

get_tree_bee_n100(force = FALSE)

Arguments

force

Logical. Re-download even if a local cache exists. Default FALSE.

Value

A multiPhylo object. Each phylogeny also has a data frame genus_family_root with root node information for every unique genus and family, usable for inserting new tips onto the phylogeny.

http://beetreeoflife.org

References

HenrĂ­quez-Piskulich, P., Hugall, A. F., & Stuart-Fox, D. (2023). A supermatrix phylogeny of the world's bees (Hymenoptera: Anthophila). bioRxiv 2023.06.16.545281. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1101/2023.06.16.545281")}

See Also

tree_bee


megatrees documentation built on May 22, 2026, 5:07 p.m.