get_tree_bird_n100: Get 100 randomly selected mega-trees of Birds from Bird Tree

View source: R/get_large_trees.R

get_tree_bird_n100R Documentation

Get 100 randomly selected mega-trees of Birds from Bird Tree

Description

The first 50 phylogenies use the Ericson backbone and the second 50 use the Hackett backbone (Jetz et al. 2012). Because of the large file size (~18 MB), this dataset is not bundled with the package and is downloaded and cached locally on first use.

Usage

get_tree_bird_n100(force = FALSE)

Arguments

force

Logical. Re-download even if a local cache exists. Default FALSE.

Value

A multiPhylo object. Each phylogeny also has a data frame genus_family_root with root node information for every unique genus and family, usable for inserting new tips onto the phylogeny.

https://data.vertlife.org/

References

Jetz, W., Thomas, G. H., Joy, J. B., Hartmann, K., & Mooers, A. O. (2012). The global diversity of birds in space and time. Nature, 491(7424), 444.

See Also

tree_bird_McTavish


megatrees documentation built on May 22, 2026, 5:07 p.m.