View source: R/get_large_trees.R
| get_tree_mammal_n100_phylacine | R Documentation |
These 100 phylogenies are randomly selected from the 1000 trees generated by Faurby et al. (2018). Because of the large file size (~6 MB), this dataset is not bundled with the package and is downloaded and cached locally on first use.
get_tree_mammal_n100_phylacine(force = FALSE)
force |
Logical. Re-download even if a local cache exists. Default FALSE. |
A multiPhylo object. Each phylogeny also has a data frame
genus_family_root with root node information for every unique genus
and family, usable for inserting new tips onto the phylogeny.
https://github.com/MegaPast2Future/PHYLACINE_1.2/blob/master/Data/Phylogenies/Complete_phylogeny.nex
Faurby, S., Davis, M., Pedersen, R. Ø., Schowanek, S. D., Antonelli, A., & Svenning, J. C. (2018). PHYLACINE 1.2: The phylogenetic atlas of mammal macroecology. Ecology, 99(11), 2626-2626.
get_tree_mammal_n100_vertlife
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.