tree_plant_Carruthers: Mega-tree of Plants based on Carruthers et al., 2026

tree_plant_CarruthersR Documentation

Mega-tree of Plants based on Carruthers et al., 2026

Description

This tree was based on Carruthers et al. (2026), which in turn was an update of the Smith and Brown (2018).

Usage

tree_plant_Carruthers

Format

A phylogeny with class "phylo". It is also a list. Compare with a normal phylo object, it has another data frame 'tree_plant_Carruthers$genus_family_root', which provides the root nodes information for every unique genus and family in the phylogeny. Such information can be used to insert new tips onto the phylogeny later.

https://www.biorxiv.org/content/10.64898/2026.01.06.695000v1

References

Carruthers et al., (2026). A large phylogenetic tree for euphyllophytes. bioRxiv.


megatrees documentation built on May 22, 2026, 5:07 p.m.