View source: R/get_large_trees.R
| get_tree_bee_n100 | R Documentation |
Because of the large file size (~5 MB), this dataset is not bundled with the package and is downloaded and cached locally on first use.
get_tree_bee_n100(force = FALSE)
force |
Logical. Re-download even if a local cache exists. Default FALSE. |
A multiPhylo object. Each phylogeny also has a data frame
genus_family_root with root node information for every unique genus
and family, usable for inserting new tips onto the phylogeny.
HenrĂquez-Piskulich, P., Hugall, A. F., & Stuart-Fox, D. (2023). A supermatrix phylogeny of the world's bees (Hymenoptera: Anthophila). bioRxiv 2023.06.16.545281. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1101/2023.06.16.545281")}
tree_bee
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.