View source: R/get_large_trees.R
| get_tree_bird_n100 | R Documentation |
The first 50 phylogenies use the Ericson backbone and the second 50 use the Hackett backbone (Jetz et al. 2012). Because of the large file size (~18 MB), this dataset is not bundled with the package and is downloaded and cached locally on first use.
get_tree_bird_n100(force = FALSE)
force |
Logical. Re-download even if a local cache exists. Default FALSE. |
A multiPhylo object. Each phylogeny also has a data frame
genus_family_root with root node information for every unique genus
and family, usable for inserting new tips onto the phylogeny.
Jetz, W., Thomas, G. H., Joy, J. B., Hartmann, K., & Mooers, A. O. (2012). The global diversity of birds in space and time. Nature, 491(7424), 444.
tree_bird_McTavish
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.