| tree_plant_Carruthers | R Documentation |
This tree was based on Carruthers et al. (2026), which in turn was an update of the Smith and Brown (2018).
tree_plant_Carruthers
A phylogeny with class "phylo". It is also a list. Compare with a normal phylo object, it has another data frame 'tree_plant_Carruthers$genus_family_root', which provides the root nodes information for every unique genus and family in the phylogeny. Such information can be used to insert new tips onto the phylogeny later.
https://www.biorxiv.org/content/10.64898/2026.01.06.695000v1
Carruthers et al., (2026). A large phylogenetic tree for euphyllophytes. bioRxiv.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.